__package_name__ = 'zfs-utils-osx'
__version__ = '1.1.0'
__author__ = 'Rick van Hattem'
__author_email__ = 'Wolph@Wol.ph'
__description__ = '''
A simple script to create and manage virtual ZFS images on OS X without
requiring repartitioning
'''
__url__ = 'https://github.com/WoLpH/zfs-utils-osx/'

